@@ -969,6 +969,110 @@ sub getZLibrary($@) {
 
 
 
+sub getX11Library($@) {
+
+    my ($platform, @suggestedHdrDir) = @_;
+
+    my $x11lib;
+    {
+        my $default;
+
+        if (-d('/usr/link/X11')) {
+            $default = '/usr/link/X11/libX11' . libSuffix($platform);
+        } elsif (-d('/usr/lib/X11')) {
+            $default = '/usr/lib/libX11' . libSuffix($platform);
+        } else {
+            $default = "libX11" . libSuffix($platform);
+        }
+        print("What is your X11 (X client) library?\n");
+        
+        my $response = prompt("library filename or 'none'", $default);
+        
+        if ($response ne "none") {
+            $x11lib = $response;
+        }
+    }
+    my $x11hdr_dir;
+    if (defined($x11lib)) {
+        my $default;
+
+        $default = "default";
+
+        print("Where are the interface headers for it?\n");
+        
+        my $response = prompt("X11 header directory", $default);
+        
+        if ($response ne "default") {
+            $x11hdr_dir = $response;
+        }
+        if (defined($x11hdr_dir)) {
+            if (!-d($x11hdr_dir)) {
+                printf("WARNING: No directory named '$x11hdr_dir' exists.\n");
+            } elsif (!-d("$x11hdr_dir/X11")) {
+                printf("WARNING: Directory '$x11hdr_dir' does not contain " .
+                       "the requisite 'X11' subdirectory\n");
+            }
+        }
+    }
+    return($x11lib, $x11hdr_dir);
+}
+
+
+
+sub getLinuxsvgaLibrary($@) {
+
+    my ($platform, @suggestedHdrDir) = @_;
+
+    my ($svgalib, $svgalibhdr_dir);
+
+    if ($platform eq "GNU") {
+        {
+            my $default;
+
+            if (-d('/usr/link/svgalib')) {
+                $default = '/usr/link/svgalib/libvga.so';
+            } elsif (-d('/usr/lib/svgalib')) {
+                $default = '/usr/lib/svgalib/libvga.so';
+            } else {
+                $default = 'libvga.so';
+            }
+            
+            print("What is your Svgalib library?\n");
+            
+            my $response = prompt("library filename or 'none'", $default);
+            
+            if ($response ne "none") {
+                $svgalib = $response;
+            }
+        }
+    }
+    if (defined($svgalib)) {
+        my $default;
+        
+        if (-d('/usr/include/svgalib')) {
+            $default = '/usr/include/svgalib';
+        } else {
+            $default = "default";
+        }
+        print("Where are the interface headers for it?\n");
+        
+        my $response = prompt("Svgalib header directory", $default);
+        
+        if ($response ne "default") {
+            $svgalibhdr_dir = $response;
+        }
+        if (defined($svgalibhdr_dir)) {
+            if (!-d($svgalibhdr_dir)) {
+                printf("WARNING: No directory named " .
+                       "'$svgalibhdr_dir' exists.\n");
+            }
+        }
+    }
+    return($svgalib, $svgalibhdr_dir);
+}
+
+
+
 sub symlink_command() {
 
     my $retval;
@@ -998,63 +1102,6 @@ sub symlink_command() {
     return $retval;
 }
 
-sub getLinuxsvgaLibrary($) {
-#-----------------------------------------------------------------------------
-#  Get the file name of the Linux SVGA library and directory of its
-#  interface headers.  If there isn't an SVGA library, return "undefined"
-#  values.
-#-----------------------------------------------------------------------------
-    my ($platform) = @_;
-
-    my ($linuxsvgahdr_dir, $linuxsvgalib);
-
-    if ($platform eq "GNU") {
-        # Look for SVGALIB 
-        if (-f "/usr/include/vga.h") {
-            $linuxsvgahdr_dir = "/usr/include";
-        } elsif (-d "/usr/include/svgalib") {
-            $linuxsvgahdr_dir = "/usr/include/svgalib";
-        } else {
-            print("Cannot find the include files for SVGALIB.  Enter the " .
-                  "directory where they reside, or none.  " .
-                  "If none, a default " .
-                  "make will not build programs that require " .
-                  "the SVGALIB library.\n");
-
-            print("Svgalib header location (none)=> ");
-
-            my $response = <STDIN>;
-            chomp($response);
-            if ($response ne "" && $response ne "none") {
-                $linuxsvgahdr_dir = $response;
-            }
-        }
-        if (defined($linuxsvgahdr_dir)) {
-            if (-f "/usr/lib/libvga.so") {
-                $linuxsvgalib = "/usr/lib/libvga.so";
-            } elsif (-f "/usr/lib/svgalib/libvga.so") {
-                $linuxsvgalib = "/usr/lib/svgalib/libvga.so";
-            } elsif (-f "/usr/link/svgalib/libvga.so") {
-                $linuxsvgalib = "/usr/link/svgalib/libvga.so";
-            } else {
-                print("Cannot find the link library for SVGALIB.  " .
-                      "Enter the full pathname of the link library, " .
-                      "or 'none'.  If 'none', " .
-                      "a default make will not build programs that require " .
-                      "the SVGALIB library.\n");
-
-                print("Svgalib link lib location (none)=> ");
-
-                my $response = <STDIN>;
-                chomp($response);
-                if ($response ne "" && $response ne "none") {
-                    $linuxsvgalib = $response;
-                }
-            }
-        }
-    }
-    return($linuxsvgalib, $linuxsvgahdr_dir);
-}
 
 
 sub help() {
@@ -1163,6 +1210,33 @@ sub needLocal($) {
 
 
 
+sub findProcessManagement($) {
+    my ($dontHaveProcessMgmtR) = @_;
+#-----------------------------------------------------------------------------
+#  Return $TRUE iff the system does not have <sys/wait.h> in its default
+#  search path.
+#-----------------------------------------------------------------------------
+    my $cflags = testCflags($FALSE);
+
+    my @cSourceCode = (
+                       "#include <sys/wait.h>\n",
+                       );
+    
+    testCompile($cflags, \@cSourceCode, \my $success);
+
+    if (!$success) {
+        print("Your system does not appear to have <sys/wait.h> in its " .
+              "standard compiler include path.  Therefore, we will build " .
+              "Netpbm with some function missing (e.g. the pm_system() " .
+              "function in libnetpbm and most of 'pamlookup'\n");
+        $$dontHaveProcessMgmtR = $TRUE;
+    } else {
+        $$dontHaveProcessMgmtR = $FALSE;
+    }
+}
+
+
+
 sub validateLibraries(@) {
     my @libList = @_;
 #-----------------------------------------------------------------------------
@@ -1504,6 +1578,8 @@ getInttypes(\my $inttypesHeaderFile);
 
 getInt64($inttypesHeaderFile, \my $haveInt64);
 
+findProcessManagement(\my $dontHaveProcessMgmt);
+
 #******************************************************************************
 #
 #  FIND THE PREREQUISITE LIBRARIES
@@ -1549,8 +1625,12 @@ my ($zlib, $zhdr_dir)       = getZLibrary($platform,
                                           $pnghdr_dir,
                                           $tiffhdr_dir,
                                           $jpeghdr_dir);
+print("\n");
+my ($x11lib, $x11hdr_dir) = getX11Library($platform); 
+
 print("\n");
 my ($linuxsvgalib, $linuxsvgahdr_dir) = getLinuxsvgaLibrary($platform); 
+
 print("\n");
 
 # We should add the JBIG and URT libraries here too.  They're a little
@@ -1657,7 +1737,7 @@ sub gnuCflags($) {
     return("CFLAGS = " . gnuOptimizeOpt($gccCommandName) . " -ffast-math " .
            " -pedantic -fno-common " . 
            "-Wall -Wno-uninitialized -Wmissing-declarations -Wimplicit " .
-           "-Wwrite-strings -Wmissing-prototypes\n");
+           "-Wwrite-strings -Wmissing-prototypes -Wundef\n");
 }
 
 my @Makefile_config;
@@ -1914,6 +1994,13 @@ if (defined($zlib)) {
     push(@Makefile_config, "ZLIB = $zlib\n");
 }
 
+if (defined($x11hdr_dir)) {
+    push(@Makefile_config, "X11HDR_DIR = $x11hdr_dir\n");
+}
+if (defined($x11lib)) {
+    push(@Makefile_config, "X11LIB = $x11lib\n");
+}
+
 if (defined($linuxsvgahdr_dir)) {
     push(@Makefile_config, "LINUXSVGAHDR_DIR = $linuxsvgahdr_dir\n");
 }
@@ -1933,6 +2020,10 @@ if ($haveInt64 ne 'Y') {
     push(@Makefile_config, "HAVE_INT64 = $haveInt64\n");
 }
 
+if ($dontHaveProcessMgmt) {
+    push(@Makefile_config, "DONT_HAVE_PROCESS_MGMT = Y\n");
+}
+
 #******************************************************************************
 #
 #  WRITE OUT THE FILE
