@@ -24,7 +24,7 @@
 
 #include "pnm.h"
 #include "shhopt.h"
-
+#include "nstring.h"
 #include "bmp.h"
 
 /* MAXCOLORS is the maximum size of a color map in a BMP image */
@@ -236,7 +236,7 @@ readOffBytes(FILE * const fp, unsigned int const nbytes) {
 
 
 static void
-BMPreadfileheader(FILE * const ifP, 
+BMPreadfileheader(FILE *         const ifP, 
                   unsigned int * const bytesReadP, 
                   unsigned int * const offBitsP) {
 
@@ -247,9 +247,12 @@ BMPreadfileheader(FILE * const ifP,
 
 
     if (GetByte(ifP) != 'B')
-        pm_error("%s is not a BMP file", ifname);
+        pm_error("'%s' is not a BMP file.  (It doesn't start with 'BM')",
+                 ifname);
     if (GetByte(ifP) != 'M')
-        pm_error("%s is not a BMP file", ifname);
+        pm_error("'%s' is not a BMP file.  (It doesn't start with 'BM')",
+                 ifname);
+
 
     fileSize = GetLong(ifP);  /* This is not always reliable. */
     xHotSpot  = GetShort(ifP);
@@ -579,18 +582,29 @@ BMPreadinfoheader(FILE *                 const ifP,
 
 static void
 BMPreadcolormap(FILE *         const ifP, 
-                unsigned int   const cBitCount, 
                 int            const class, 
                 xel **         const colormapP, 
                 int            const cmapsize,
                 unsigned int * const bytesReadP) {
+/*----------------------------------------------------------------------------
+   Read the color map from the present position in the input BMP file
+   *ifP.
+
+   The map has 'cmapsize' entries in it.  cmapsize == 0 means there is
+   no color map.
+
+   We return a color map as *colormapP.  If there is no color map in the
+   BMP, this is just an arbitrary color map.
+ 
+   'class' is the class of BMP image - Windows or OS/2.
+-----------------------------------------------------------------------------*/
 
     int i;
 
     xel * colormap;
     unsigned int bytesRead;
 
-    colormap = pnm_allocrow(cmapsize);
+    colormap = pnm_allocrow(MAX(1,cmapsize));
     
     bytesRead = 0;  /* initial value */
 
@@ -1185,7 +1199,7 @@ readColorMap(FILE *               const ifP,
 
     unsigned int bytesRead;
 
-    BMPreadcolormap(ifP, BMPheader.cBitCount, BMPheader.class, 
+    BMPreadcolormap(ifP, BMPheader.class, 
                     colorMapP, BMPheader.cmapsize, &bytesRead);
 
     *posP += bytesRead;
@@ -1197,7 +1211,7 @@ readColorMap(FILE *               const ifP,
                    bytesRead,
                    BMPlencolormap(BMPheader.class, BMPheader.cBitCount, 
                                   BMPheader.cmapsize));
-    }
+}
 }
 
 
@@ -1415,9 +1429,9 @@ main(int argc, char ** argv) {
         /* Number of bits in BMP raster for each pixel */
     struct pixelformat pixelformat;
         /* Format of the raster bits for a single pixel */
-    xel *colormap;
-        /* Malloc'ed colormap (palette) from the BMP.  Undefined if
-           not a colormapped BMP.
+    xel * colormap;
+        /* Malloc'ed colormap (palette) from the BMP.  Contents of map
+           undefined if not a colormapped BMP.
          */
 
     pnm_init(&argc, argv);
@@ -1425,7 +1439,7 @@ main(int argc, char ** argv) {
     parse_command_line(argc, argv, &cmdline);
 
     ifP = pm_openr(cmdline.input_filespec);
-    if (strcmp(cmdline.input_filespec, "-"))
+    if (streq(cmdline.input_filespec, "-"))
         ifname = "Standard Input";
     else 
         ifname = cmdline.input_filespec;
@@ -1459,3 +1473,5 @@ main(int argc, char ** argv) {
 
     return 0;
 }
+
+
