@@ -178,10 +178,10 @@ interpret_density(const char *        const densityString,
                 if (matched < 3) 
                     densityP->unit = DEN_UNSPECIFIED;
                 else {
-                    if (STREQ(unitName, "dpi") || STREQ(unitName, "DPI"))
+                    if (streq(unitName, "dpi") || streq(unitName, "DPI"))
                         densityP->unit = DEN_DOTS_PER_INCH;
-                    else if (STREQ(unitName, "dpcm") ||
-                             STREQ(unitName, "DPCM"))
+                    else if (streq(unitName, "dpcm") ||
+                             streq(unitName, "DPCM"))
                         densityP->unit = DEN_DOTS_PER_CM;
                     else
                         pm_error("Unrecognized unit '%s' in the density value "
@@ -298,11 +298,11 @@ parseCommandLine(const int argc, char ** argv,
     if (dctval == NULL)
         cmdlineP->dct_method = JDCT_DEFAULT;
     else {
-        if (STREQ(dctval, "int"))
+        if (streq(dctval, "int"))
             cmdlineP->dct_method = JDCT_ISLOW;
-        else if (STREQ(dctval, "fast"))
+        else if (streq(dctval, "fast"))
             cmdlineP->dct_method = JDCT_IFAST;
-        else if (STREQ(dctval, "float"))
+        else if (streq(dctval, "float"))
             cmdlineP->dct_method = JDCT_FLOAT;
         else
             pm_error("Invalid value for the --dct option: '%s'.", dctval);
@@ -318,9 +318,9 @@ parseCommandLine(const int argc, char ** argv,
         pm_error("Smoothing factor %d is greater than 100 (%%).",
                  cmdlineP->smoothing_factor);
 
-    if (STREQ(cmdlineP->input_filespec, "=") &&
+    if (streq(cmdlineP->input_filespec, "=") &&
         cmdlineP->exif_filespec && 
-        STREQ(cmdlineP->exif_filespec, "-"))
+        streq(cmdlineP->exif_filespec, "-"))
 
         pm_error("Cannot have both input image and exif header be from "
                  "Standard Input.");
@@ -643,16 +643,18 @@ translate_row(const pixel pnm_buffer[],
 
 
 static void
-convert_scanlines(struct jpeg_compress_struct *cinfo_p, FILE *input_file,
-                  const pixval maxval, const int input_fmt,
-                  JSAMPLE xlate_table[]){
+convert_scanlines(struct jpeg_compress_struct * const cinfo_p,
+                  FILE *                        const input_file,
+                  pixval                        const maxval,
+                  int                           const input_fmt,
+                  JSAMPLE                             xlate_table[]){
 /*----------------------------------------------------------------------------
    Read scan lines from the input file, which is already opened in the 
    netpbm library sense and ready for reading, and write them to the 
    output JPEG object.  Translate the pnm sample values to JPEG sample
    values through the thable xlate_table[].
 -----------------------------------------------------------------------------*/
-  xel* pnm_buffer;  
+  xel * pnm_buffer;  
     /* contains the row of the input image currently being processed,
        in pnm_readpnmrow format
     */
@@ -680,13 +682,13 @@ convert_scanlines(struct jpeg_compress_struct *cinfo_p, FILE *input_file,
                   xlate_table);
     jpeg_write_scanlines(cinfo_p, buffer, 1);
     if (cinfo_p->err->trace_level > 1) 
-      pm_message("Done.");
+        pm_message("Done.");
   }
 
   pnm_freerow(pnm_buffer);
   /* Dont' worry about the compressor input buffer; it gets freed 
      automatically
-     */
+  */
 
 }
 
