@@ -630,7 +630,6 @@ pnmtopng_error_handler(png_structp     const png_ptr,
 /* The following variables belong to getChv() and freeChv() */
 static bool getChv_computed = FALSE;
 static colorhist_vector getChv_chv;
-static int getChv_colors;
 
 
 
@@ -657,21 +656,29 @@ getChv(FILE *             const ifP,
 
    Don't spend the time to read the file if this subroutine has been called
    before.  In that case, just assume the inputs are all the same and return
-   the previously computed information.
+   the previously computed information.  Ick.
 
    *chvP is in static program storage.
 -----------------------------------------------------------------------------*/
+    static unsigned int getChv_colors;
+
     if (!getChv_computed) {
+        int colorCount;
         if (verbose) 
             pm_message ("Finding colors in input image...");
 
         pm_seek2(ifP, &imagepos, sizeof(imagepos));
         getChv_chv = ppm_computecolorhist2(ifP, cols, rows, maxval, format, 
-                                           MAXCOLORS, &getChv_colors);
+                                           maxColors, &colorCount);
         
-        if (getChv_chv)
-            pm_message ("%d colors found", getChv_colors);
+        getChv_colors = colorCount;
 
+        if (verbose) {
+            if (getChv_chv)
+                pm_message("%u colors found", getChv_colors);
+            else
+                pm_message("Too many colors (more than %u) found", maxColors);
+        }
         getChv_computed = TRUE;
     }
     *chvP = getChv_chv;
@@ -1044,11 +1051,11 @@ readOrderedPalette(FILE *         const pfp,
         pm_error("ordered-palette image contains %d pixels.  Maximum is %d",
                  *ordered_palette_size_p, MAXCOLORS);
     if (verbose)
-      pm_message ("%d colors found", *ordered_palette_size_p);
+        pm_message("%u colors found", *ordered_palette_size_p);
 
     {
-        int j;
-        int row;
+        unsigned int j;
+        unsigned int row;
         j = 0;  /* initial value */
         for (row = 0; row < rows; ++row) {
             int col;
@@ -1400,8 +1407,8 @@ makeOneColorTransparentInPalette(xel            const transColor,
                           &transparentIndex, &distance);
 
     if (distance != 0 && exact) {
-        pm_message ("specified transparent color not present in palette; "
-                    "ignoring -transparent");
+        pm_message("specified transparent color not present in palette; "
+                   "ignoring -transparent");
         errorlevel = PNMTOPNG_WARNING_LEVEL;
     } else {        
         /* Swap this with the first entry in the palette */
@@ -1460,8 +1467,8 @@ findOrAddBackgroundInPalette(pixel          const backColor,
         *backgroundIndexP = backgroundIndex;
         if (verbose) {
             pixel const p = palette_pnm[*backgroundIndexP];
-            pm_message ("background color (%u, %u, %u) appears in image.",
-                        PPM_GETR(p), PPM_GETG(p), PPM_GETB(p));
+            pm_message("background color (%u, %u, %u) appears in image.",
+                       PPM_GETR(p), PPM_GETG(p), PPM_GETB(p));
         }
     } else {
         /* Try to add the background color, opaque, to the palette. */
@@ -1482,11 +1489,11 @@ findOrAddBackgroundInPalette(pixel          const backColor,
             closestColorInPalette(backColor, palette_pnm, *paletteSizeP,
                                   backgroundIndexP, NULL);
             errorlevel = PNMTOPNG_WARNING_LEVEL;
-            if (verbose) {
+            {
                 pixel const p = palette_pnm[*backgroundIndexP];
-                pm_message ("no room in palette for background color; "
-                            "using closest match (%u, %u, %u) instead",
-                            PPM_GETR(p), PPM_GETG(p), PPM_GETB(p));
+                pm_message("no room in palette for background color; "
+                           "using closest match (%u, %u, %u) instead",
+                           PPM_GETR(p), PPM_GETG(p), PPM_GETB(p));
             }
         }
     }
@@ -2516,7 +2523,7 @@ convertpnm(struct cmdlineInfo const cmdline,
         info_ptr->valid |= PNG_INFO_hIST;
         info_ptr->hist = histogram;
         if (verbose)
-            pm_message ("histogram created");
+            pm_message("histogram created");
     }
   } else { /* color_type != PNG_COLOR_TYPE_PALETTE */
     if (info_ptr->color_type == PNG_COLOR_TYPE_GRAY ||
