@@ -128,7 +128,13 @@ boolean niceProcesses = FALSE;
 boolean forceIalign = FALSE;
 int     machineNumber = -1;
 boolean remoteIO = FALSE;
-boolean separateConversion;
+bool separateConversion;
+    /* The I/O server will convert from the input format to the base format,
+       and the slave will convert from the base format to the YUV internal
+       format.  If false, the I/O server assumes the input format is the
+       base format and converts from the base format to the YUV internal
+       format; the slave does no conversion.
+    */
 time_t  IOtime = 0;
 extern char encoder_name[];
 int     ClientPid[MAX_MACHINES+4];
@@ -139,7 +145,7 @@ int     ClientPid[MAX_MACHINES+4];
  *=====================*/
 
 
-static void GNU_PRINTF_ATTR
+static void PM_GNU_PRINTF_ATTR(1,2)
 machineDebug(const char format[], ...) {
 
     va_list args;
@@ -158,7 +164,7 @@ machineDebug(const char format[], ...) {
 
 
 
-static void GNU_PRINTF_ATTR
+static void PM_GNU_PRINTF_ATTR(1,2)
 errorExit(const char format[], ...) {
 
     const char * const hostname = GetHostName();
@@ -624,9 +630,7 @@ static int safe_fork(command)       /* fork child process and remember its PID *
  *
  *===========================================================================*/
 void
-SetIOConvert(separate)
-    boolean separate;
-{
+SetIOConvert(bool const separate) {
     separateConversion = separate;
 }
 
@@ -789,29 +793,26 @@ routeFromSocketToDisk(int              const otherSock,
 
 
 static void
-readFrameWriteToSocket(struct inputSource * const inputSourceP,
-                       int                  const otherSock,
-                       int                  const frameNumber) {
-
-    /* should read in frame, then write to socket */
-
-    if (debugSockets) {
-        fprintf(stdout, "I/O SERVER GETTING FRAME %d\n", frameNumber);
-        fflush(stdout);
-    }
-
-    if (separateConversion) {
-        FILE * filePtr;
+readConvertWriteToSocket(struct inputSource * const inputSourceP,
+                         int                  const otherSock,
+                         int                  const frameNumber,
+                         bool *               const endOfStreamP) {
+/*----------------------------------------------------------------------------
+   Get the frame numbered 'frameNumber' from input source
+   *inputSourceP, apply format conversion User requested, and write
+   the "base format" result to socket 'otherSock'.
+-----------------------------------------------------------------------------*/
+    FILE * convertedFileP;
+    
+    convertedFileP = ReadIOConvert(inputSourceP, frameNumber);
+    if (convertedFileP) {
         bool eof;
-
-        /* do conversion and send right to the socket */
-        filePtr = ReadIOConvert(inputSourceP, frameNumber);
         eof = FALSE;  /* initial value */
         while (!eof) {
             unsigned char buffer[1024];
             unsigned int numBytes;
-
-            numBytes = fread(buffer, 1, sizeof(buffer), filePtr);
+            
+            numBytes = fread(buffer, 1, sizeof(buffer), convertedFileP);
             
             if (numBytes > 0) {
                 WriteInt(otherSock, numBytes);
@@ -821,30 +822,73 @@ readFrameWriteToSocket(struct inputSource * const inputSourceP,
         }
         
         if (strcmp(ioConversion, "*") == 0 )
-            fclose(filePtr);
+            fclose(convertedFileP);
         else
-            pclose(filePtr);
-    } else {
-        MpegFrame * frameP;
-
-        frameP = Frame_New(frameNumber, 'i');
-
-        ReadFrame(frameP, inputSourceP, frameNumber, inputConversion);
+            pclose(convertedFileP);
         
+        *endOfStreamP = FALSE;
+    } else
+        *endOfStreamP = TRUE;
+}
+
+
+
+static void
+readWriteYuvToSocket(struct inputSource * const inputSourceP,
+                     int                  const otherSock,
+                     int                  const frameNumber,
+                     bool *               const endOfStreamP) {
+/*----------------------------------------------------------------------------
+   Read Frame number 'frameNumber' from the input source *inputSourceP,
+   assuming it is in base format, and write its contents in YUV format
+   to socket 'otherSock'.
+
+   Wait for acknowledgement that consumer has received it.
+-----------------------------------------------------------------------------*/
+    MpegFrame * frameP;
+
+    frameP = Frame_New(frameNumber, 'i');
+    
+    ReadFrame(frameP, inputSourceP, frameNumber, inputConversion,
+              endOfStreamP);
+    
+    if (!*endOfStreamP) {
         writeYUVOrig(otherSock, Fsize_x, Fsize_y, frameP);
-
-        Frame_Free(frameP);
-
-        /* now, make sure we don't leave until other processor read
-           everything 
-        */
-
+        
         {
+            /* Make sure we don't leave until other processor read
+               everything
+            */
             int dummy;
             ReadInt(otherSock, &dummy);
             assert(dummy == 0);
         }
     }
+    Frame_Free(frameP);
+}
+
+
+
+static void
+readFrameWriteToSocket(struct inputSource * const inputSourceP,
+                       int                  const otherSock,
+                       int                  const frameNumber,
+                       bool *               const endOfStreamP) {
+/*----------------------------------------------------------------------------
+   Read Frame number 'frameNumber' from the input source *inputSourceP
+   and write it to socket 'otherSock'.
+-----------------------------------------------------------------------------*/
+    if (debugSockets) {
+        fprintf(stdout, "I/O SERVER GETTING FRAME %d\n", frameNumber);
+        fflush(stdout);
+    }
+
+    if (separateConversion)
+        readConvertWriteToSocket(inputSourceP, otherSock, frameNumber,
+                                 endOfStreamP);
+    else
+        readWriteYuvToSocket(inputSourceP, otherSock, frameNumber,
+                             endOfStreamP);
 
     if (debugSockets) {
         fprintf(stdout, "====I/O SERVER:  READ FRAME %d\n", frameNumber);
@@ -860,8 +904,8 @@ processNextConnection(int                  const serverSocket,
                       unsigned char **     const bigBufferP,
                       unsigned int *       const bigBufferSizeP) {
 
-    int       otherSock;
-    int command;
+    int          otherSock;
+    int          command;
     const char * error;
     
     AcceptConnection(serverSocket, &otherSock, &error);
@@ -883,10 +927,25 @@ processNextConnection(int                  const serverSocket,
     case -4:
         routeFromSocketToDisk(otherSock, bigBufferP, bigBufferSizeP);
         break;
-    default:
-        readFrameWriteToSocket(inputSourceP, otherSock, command);
+    default: {
+        unsigned int const frameNumber = command;
+
+        bool endOfStream;
+
+        readFrameWriteToSocket(inputSourceP, otherSock, frameNumber,
+                               &endOfStream);
+
+        if (endOfStream) {
+            /* We don't do anything.  Closing the socket with having written
+               anything is our signal that there is no more input.
+
+               (Actually, Ppmtompeg cannot handle stream input in parallel
+               mode -- this code is just infrastructure so maybe it can some
+               day).
+            */
+        }
+    }
     }
-    
     close(otherSock);
 }
  
@@ -1010,7 +1069,6 @@ GetRemoteFrame(MpegFrame * const frameP,
    
    This is intended for use by a child.
 -----------------------------------------------------------------------------*/
-
     int           clientSocket;
     const char * error;
 
@@ -1053,9 +1111,13 @@ GetRemoteFrame(MpegFrame * const frameP,
                 fwrite(buffer, 1, numBytes, filePtr);
             } while ( numBytes == sizeof(buffer) );
             fflush(filePtr);
-            rewind(filePtr);
-            /* now do slave conversion */
-            ReadFrameFile(frameP, filePtr, slaveConversion);
+            {
+                bool endOfStream;
+                rewind(filePtr);
+                /* I/O Server gave us base format.  Read it as an MpegFrame */
+                ReadFrameFile(frameP, filePtr, slaveConversion, &endOfStream);
+                assert(!endOfStream);
+            }
             fclose(filePtr);
         } else {
             Frame_AllocYCC(frameP);
@@ -1065,6 +1127,7 @@ GetRemoteFrame(MpegFrame * const frameP,
                         getenv("HOST"), frameNumber);
                 fflush(stdout);
             }
+            /* I/O Server gave us internal YUV format.  Read it as MpegFrame */
             readYUVOrig(clientSocket, yuvWidth, yuvHeight, frameP);
         }
     }
@@ -1073,7 +1136,7 @@ GetRemoteFrame(MpegFrame * const frameP,
 
     close(clientSocket);
 
-    if ( debugSockets ) {
+    if (debugSockets) {
         fprintf(stdout, "MACHINE %s READ COMPLETELY FRAME %d\n",
                 getenv("HOST"), frameNumber);
         fflush(stdout);
