@@ -542,6 +542,10 @@ getUserFrameFile(void *       const handle,
     
     struct inputSource * const inputSourceP = (struct inputSource *) handle;
 
+    if (inputSourceP->stdinUsed)
+        pm_error("You cannot combine frames from Standard Input.");
+            /* Because Caller detects end of frames by EOF */
+    
     if (frameNumber >= inputSourceP->numInputFiles)
         *ifPP = NULL;
     else {
@@ -703,9 +707,9 @@ main(int argc, char **argv) {
             } else
                 runMaster(params.inputSourceP,
                           cmdline.paramFileName, outputFileName);
-        } else if ( cmdline.function == COMBINE_GOPS )
+        } else if (cmdline.function == COMBINE_GOPS)
             GOPsToMPEG(params.inputSourceP, outputFileName, ofP);
-        else if ( cmdline.function == COMBINE_FRAMES )
+        else if (cmdline.function == COMBINE_FRAMES)
             FramesToMPEG(ofP, params.inputSourceP,
                          &getUserFrameFile, &nullDisposeFile);
     } 
