@@ -703,8 +703,7 @@ pnm_readpaminit(FILE *       const file,
         pamP->maxval = (sample) maxval;
         pamP->depth = 3;
         strcpy(pamP->tuple_type, PAM_PPM_TUPLETYPE);
-    }
-        break;
+    } break;
 
     case PGM_TYPE: {
         gray maxval;
@@ -712,8 +711,7 @@ pnm_readpaminit(FILE *       const file,
         pamP->maxval = (sample) maxval;
         pamP->depth = 1;
         strcpy(pamP->tuple_type, PAM_PGM_TUPLETYPE);
-    }
-    break;
+    } break;
 
     case PBM_TYPE:
         pbm_readpbminitrest(pamP->file, &pamP->width,&pamP->height);
