@@ -15,8 +15,9 @@
 
 #include <assert.h>
 
-#include "pam.h"
+#include "pm_c_util.h"
 #include "mallocvar.h"
+#include "pam.h"
 #include "pammap.h"
 
 
@@ -170,12 +171,12 @@ pnm_lookuptuple(struct pam *    const pamP,
 
 
 static void
-addColorToHash(tuple          const color, 
-               tuplehash      const tuplefreqhash,
-               struct pam *   const pamP,
-               unsigned int   const maxsize,
-               unsigned int * const sizeP,
-               bool *         const fullP) {
+addColorOccurrenceToHash(tuple          const color, 
+                         tuplehash      const tuplefreqhash,
+                         struct pam *   const pamP,
+                         unsigned int   const maxsize,
+                         unsigned int * const sizeP,
+                         bool *         const fullP) {
                
     unsigned int const hashvalue = pnm_hashtuple(pamP, color);
             
@@ -186,7 +187,8 @@ addColorToHash(tuple          const color,
          p = p->next);
 
     if (p) {
-        p->tupleint.value++;
+        /* It's in the hash; just tally one more occurence */
+        ++p->tupleint.value;
         *fullP = FALSE;
     } else {
         /* It's not in the hash yet, so add it (if allowed) */
@@ -208,6 +210,43 @@ addColorToHash(tuple          const color,
 
 
 
+void
+pnm_addtuplefreqoccurrence(struct pam *   const pamP,
+                           tuple          const value,
+                           tuplehash      const tuplefreqhash,
+                           int *          const firstOccurrenceP) {
+
+    unsigned int const hashvalue = pnm_hashtuple(pamP, value);
+            
+    struct tupleint_list_item * p;
+
+    for (p = tuplefreqhash[hashvalue]; 
+         p && !pnm_tupleequal(pamP, p->tupleint.tuple, value);
+         p = p->next);
+
+    if (p) {
+        /* It's in the hash; just tally one more occurence */
+        ++p->tupleint.value;
+        *firstOccurrenceP = FALSE;
+    } else {
+        struct tupleint_list_item * p;
+
+        /* It's not in the hash yet, so add it */
+        *firstOccurrenceP = TRUE;
+
+        p = allocTupleIntListItem(pamP);
+        if (p == NULL)
+            pm_error("out of memory computing hash table");
+
+        pnm_assigntuple(pamP, p->tupleint.tuple, value);
+        p->tupleint.value = 1;
+        p->next = tuplefreqhash[hashvalue];
+        tuplefreqhash[hashvalue] = p;
+    }
+}
+
+
+
 static void
 computehashrecoverable(struct pam *   const pamP,
                        tuple **       const tupleArray, 
@@ -253,8 +292,8 @@ computehashrecoverable(struct pam *   const pamP,
         }
         for (col = 0; col < pamP->width && !full; ++col) {
             pnm_scaletuple(pamP, *colorP, tuplerow[col], freqPam.maxval);
-            addColorToHash(*colorP, *tuplefreqhashP, &freqPam, maxsize, 
-                           sizeP, &full);
+            addColorOccurrenceToHash(
+                *colorP, *tuplefreqhashP, &freqPam, maxsize, sizeP, &full);
         }
     }
 
@@ -387,7 +426,8 @@ pnm_alloctupletable(const struct pam * const pamP,
 
 
 void
-pnm_freetupletable(struct pam * const pamP, tupletable const tupletable) {
+pnm_freetupletable(struct pam * const pamP,
+                   tupletable   const tupletable) {
 
     /* Note that the address 'tupletable' is, to the operating system, 
        the address of a larger block of memory that contains not only 
@@ -400,6 +440,15 @@ pnm_freetupletable(struct pam * const pamP, tupletable const tupletable) {
 
 
 
+void
+pnm_freetupletable2(struct pam * const pamP,
+                    tupletable2  const tupletable) {
+
+    pnm_freetupletable(pamP, tupletable.table);
+}
+
+
+
 static tupletable
 tuplehashtotable(const struct pam * const pamP,
                  tuplehash          const tuplehash,
