@@ -115,7 +115,7 @@ pm_perror(const char reason[] ) {
 
 
 
-void GNU_PRINTF_ATTR
+void PM_GNU_PRINTF_ATTR(1,2)
 pm_message(const char format[], ...) {
 
     va_list args;
@@ -132,7 +132,7 @@ pm_message(const char format[], ...) {
 
 
 
-void GNU_PRINTF_ATTR
+void PM_GNU_PRINTF_ATTR(1,2)
 pm_error(const char format[], ...) {
     va_list args;
 
@@ -152,19 +152,28 @@ pm_error(const char format[], ...) {
 
 /* Variable-sized arrays. */
 
-char*
-pm_allocrow(int const cols, int const size) {
+char *
+pm_allocrow(unsigned int const cols,
+            unsigned int const size) {
+
     char * itrow;
 
-    itrow = malloc( cols * size );
-    if ( itrow == NULL )
-        pm_error( "out of memory allocating a row" );
+    if (UINT_MAX / cols < size)
+        pm_error("Arithmetic overflow multiplying %u by %u to get the "
+                 "size of a row to allocate.", cols, size);
+
+    itrow = malloc(cols * size);
+    if (itrow == NULL)
+        pm_error("out of memory allocating a row");
+
     return itrow;
-    }
+}
+
+
 
 void
 pm_freerow(char * const itrow) {
-    free( itrow );
+    free(itrow);
 }
 
 
@@ -719,6 +728,77 @@ tmpDir(void) {
 
 
 
+static int
+mkstempx(char * const filenameBuffer) {
+/*----------------------------------------------------------------------------
+  This is meant to be equivalent to POSIX mkstemp().
+
+  On some old systems, mktemp() is a security hazard that allows a hacker
+  to read or write our temporary file or cause us to read or write some
+  unintended file.  On other systems, mkstemp() does not exist.
+
+  A Windows/mingw environment is one which doesn't have mkstemp()
+  (2006.06.15).
+
+  We assume that if a system doesn't have mkstemp() that its mktemp()
+  is safe, or that the total situation is such that the problems of
+  mktemp() are not a problem for the user.
+-----------------------------------------------------------------------------*/
+    int retval;
+    int fd;
+    unsigned int attempts;
+    bool gotFile;
+    bool error;
+
+    for (attempts = 0, gotFile = FALSE, error = FALSE;
+         !gotFile && !error && attempts < 100;
+         ++attempts) {
+
+        char * rc;
+        rc = mktemp(filenameBuffer);
+
+        if (rc == NULL)
+            error = TRUE;
+        else {
+            int rc;
+
+            rc = open(filenameBuffer, O_CREAT | O_EXCL, S_IRUSR | S_IWUSR);
+
+            if (rc == 0) {
+                fd = rc;
+                gotFile = TRUE;
+            } else {
+                if (errno == EEXIST) {
+                    /* We'll just have to keep trying */
+                } else 
+                    error = TRUE;
+            }
+        }
+    }    
+    if (gotFile)
+        retval = fd;
+    else
+        retval = -1;
+
+    return retval;
+}
+
+
+
+static int
+mkstemp2(char * const filenameBuffer) {
+
+#if HAVE_MKSTEMP
+    if (0)
+        mkstempx(NULL);  /* defeat compiler unused function warning */
+    return mkstemp(filenameBuffer);
+#else
+    return mkstempx(filenameBuffer);
+#endif
+}
+
+
+
 void
 pm_make_tmpfile(FILE **       const filePP,
                 const char ** const filenameP) {
@@ -746,13 +826,14 @@ pm_make_tmpfile(FILE **       const filePP,
     if (filenameTemplate == NULL)
         pm_error("Unable to allocate storage for temporary file name");
 
-    filenameBuffer = (char*)filenameTemplate;
-    fd = mkstemp(filenameBuffer);
+    filenameBuffer = strdup(filenameTemplate);
+
+    fd = mkstemp2(filenameBuffer);
 
     if (fd < 0)
         pm_error("Unable to create temporary file according to name "
                  "pattern '%s'.  mkstemp() failed with "
-                 "errno %d (%s)", filenameBuffer, errno, strerror(errno));
+                 "errno %d (%s)", filenameTemplate, errno, strerror(errno));
     else {
         fileP = fdopen(fd, "w+b");
 
@@ -760,6 +841,8 @@ pm_make_tmpfile(FILE **       const filePP,
             pm_error("Unable to create temporary file.  fdopen() failed "
                      "with errno %d (%s)", errno, strerror(errno));
     }
+    strfree(filenameTemplate);
+
     *filenameP = filenameBuffer;
     *filePP = fileP;
 }
