@@ -34,27 +34,6 @@ extern "C" {
 #endif
 
 
-/* GNU_PRINTF_ATTR lets the GNU compiler check pm_message() and pm_error()
-   calls to be sure the arguments match the format string, thus preventing
-   runtime segmentation faults and incorrect messages.
-*/
-#ifdef __GNUC__
-#define GNU_PRINTF_ATTR __attribute__ ((format (printf, 1,2)))
-#else
-#define GNU_PRINTF_ATTR
-#endif
-
-
-/* PURE_FN_ATTR is the attribute you add to a function declaration
-   that indicates it's a true function -- has no side effects and return
-   value is not influenced by anything except its arguments.
-*/
-#ifdef __GNUC__
-#define PURE_FN_ATTR __attribute__ ((const))
-#else
-#define PURE_FN_ATTR
-#endif
-
 /* Definitions to make Netpbm programs work with either ANSI C or C
    Classic.
 
@@ -79,6 +58,27 @@ extern "C" {
 #define ARGS(alist) alist
 
 
+/* PM_GNU_PRINTF_ATTR lets the GNU compiler check pm_message() and pm_error()
+   calls to be sure the arguments match the format string, thus preventing
+   runtime segmentation faults and incorrect messages.
+*/
+#ifdef __GNUC__
+#define PM_GNU_PRINTF_ATTR(a,b) __attribute__ ((format (printf, a, b)))
+#else
+#define PM_GNU_PRINTF_ATTR
+#endif
+
+
+/* PURE_FN_ATTR is the attribute you add to a function declaration
+   that indicates it's a true function -- has no side effects and return
+   value is not influenced by anything except its arguments.
+*/
+#ifdef __GNUC__
+#define PURE_FN_ATTR __attribute__ ((const))
+#else
+#define PURE_FN_ATTR
+#endif
+
 typedef struct {
     /* Coordinates of a pixel within an image.  Row 0 is the top row.
        Column 0 is the left column.
@@ -116,8 +116,9 @@ pm_nextimage(FILE * const file, int * const eofP);
 char** 
 pm_allocarray (int const cols, int const rows, int const size );
 
-char* 
-pm_allocrow (int const cols, int const size);
+char * 
+pm_allocrow(unsigned int const cols,
+            unsigned int const size);
 
 void 
 pm_freearray (char** const its, int const rows);
@@ -150,10 +151,10 @@ void
 pm_setjmpbufsave(jmp_buf *  const jmpbufP,
                  jmp_buf ** const oldJmpbufPP);
 
-void GNU_PRINTF_ATTR
+void PM_GNU_PRINTF_ATTR(1,2)
 pm_message (const char format[], ...);     
 
-void GNU_PRINTF_ATTR
+void PM_GNU_PRINTF_ATTR(1,2)
 pm_error (const char reason[], ...);       
 
 /* Obsolete - use helpful error message instead */
